searchData={"items":[{"type":"module","title":"ExAws.ElasticLoadBalancing","doc":"Operations on AWS ElasticLoadBalancing\n\nAWS ElasticLoadBalancing provides a reliable, scalable, and flexible monitoring solution\nfor your AWS resources. This module provides functionality for only classic load balancers.\nSee `ExAws.ElasticLoadBalancingV2` for the API for application and network load balancers.\n\nMore information:\n* [Elastic Load Balancing User Guide][User_Guide]\n* [Elastic Load Balancing API][API_Doc]\n* [Amazon Resource Names (ARNs)][ARN_Doc]\n\n[User_Guide]: http://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/\n[API_Doc]: http://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/\n[ARN_Doc]: http://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html","ref":"ExAws.ElasticLoadBalancing.html"},{"type":"function","title":"ExAws.ElasticLoadBalancing.add_tags/2","doc":"Adds the specified tags to the specified load balancer. Each load balancer can have a\nmaximum of 10 tags\n\nEach tag consists of a key and an optional value. If a tag with the same key is already\nassociated with the load balancer, `add_tags/2` updates its value.\n\nFor more information, see [Tag Your Classic Load Balancer in the Classic Load Balancers\nGuide](https://amzn.to/2Ou2dCS).","ref":"ExAws.ElasticLoadBalancing.html#add_tags/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.add_tags/2","doc":"* load_balancer_names (`List` of `String`) - The name of the load balancer. You can specify\n  one load balancer only\n\n  * tags (`List` of `t:tag/0`) - the tags to apply to the specified balancer","ref":"ExAws.ElasticLoadBalancing.html#add_tags/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.add_tags/2","doc":"iex> ExAws.ElasticLoadBalancing.add_tags([\"classic1\"], [%{key: \"Hello\", value: \"test\"}])\n    %ExAws.Operation.Query{\n      action: :add_tags,\n      params: %{\n        \"Action\" => \"AddTags\",\n        \"LoadBalancerNames.member.1\" => \"classic1\",\n        \"Tags.member.1.Key\" => \"Hello\",\n        \"Tags.member.1.Value\" => \"test\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#add_tags/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.apply_security_groups_to_load_balancer/2","doc":"Associates one or more security groups with your load balancer in a virtual private cloud (VPC)\n\nThe specified security groups override the previously associated security groups.\nFor more information, see [Security Groups for Load Balancers in a VPC](https://amzn.to/2JDqK9A)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#apply_security_groups_to_load_balancer/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.apply_security_groups_to_load_balancer/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * security_groups (`List` of `String`) - The IDs of the security groups to associate with the\n  load balancer. Note that you cannot specify the name of the security group","ref":"ExAws.ElasticLoadBalancing.html#apply_security_groups_to_load_balancer/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.apply_security_groups_to_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancing.apply_security_groups_to_load_balancer(\"mylb\", [\"sg1\", \"sg2\"])\n    %ExAws.Operation.Query{\n      action: :apply_security_groups_to_load_balancer,\n      params: %{\n        \"Action\" => \"ApplySecurityGroupsToLoadBalancer\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"SecurityGroups.member.1\" => \"sg1\",\n        \"SecurityGroups.member.2\" => \"sg2\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#apply_security_groups_to_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.attach_load_balancer_to_subnets/2","doc":"Adds one or more subnets to the set of configured subnets for the specified\nload balancer\n\nThe load balancer evenly distributes requests across all registered subnets. For\nmore information, see [Add or Remove Subnets for Your Load Balancer in a\nVPC](https://amzn.to/2YqKJvD) in the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#attach_load_balancer_to_subnets/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.attach_load_balancer_to_subnets/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * subnets (`List` of `String`) - the IDs of the subnets to add. You can add only\n  one subnet per Availability Zone.","ref":"ExAws.ElasticLoadBalancing.html#attach_load_balancer_to_subnets/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.attach_load_balancer_to_subnets/2","doc":"iex> ExAws.ElasticLoadBalancing.attach_load_balancer_to_subnets(\"mylb\", [\"subnet-3561b05e\"])\n    %ExAws.Operation.Query{\n      action: :attach_load_balancer_to_subnets,\n      params: %{\n        \"Action\" => \"AttachLoadBalancerToSubnets\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"Subnets.member.1\" => \"subnet-3561b05e\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#attach_load_balancer_to_subnets/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.configure_health_check/2","doc":"Specifies the health check settings to use when evaluating the health state of your EC2 instances\n\nFor more information, see [Configure Health Checks for Your Load Balancer](https://amzn.to/2HWBv4z)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#configure_health_check/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.configure_health_check/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * health_check (`t:health_check/0`) - configuration information","ref":"ExAws.ElasticLoadBalancing.html#configure_health_check/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.configure_health_check/2","doc":"iex> ExAws.ElasticLoadBalancing.configure_health_check(\"mylb\",\n    ...> %{healthy_threshold: 2,\n    ...> unhealthy_threshold: 2,\n    ...> target: \"HTTP:80/ping\",\n    ...> interval: 30,\n    ...> timeout: 3})\n    %ExAws.Operation.Query{\n      action: :configure_health_check,\n      params: %{\n        \"Action\" => \"ConfigureHealthCheck\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"HealthCheck.HealthyThreshold\" => 2,\n        \"HealthCheck.UnhealthyThreshold\" => 2,\n        \"HealthCheck.Target\" => \"HTTP:80/ping\",\n        \"HealthCheck.Interval\" => 30,\n        \"HealthCheck.Timeout\" => 3,\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#configure_health_check/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.create_app_cookie_stickiness_policy/3","doc":"Generates a stickiness policy with sticky session lifetimes that follow\nthat of an application-generated cookie\n\nThis policy can be associated only with HTTP/HTTPS listeners.\n\nThis policy is similar to the policy created by `create_lb_cookie_stickiness_policy/3`, except\nthat the lifetime of the special Elastic Load Balancing cookie, AWSELB, follows the lifetime\nof the application-generated cookie specified in the policy configuration. The load balancer\nonly inserts a new stickiness cookie when the application response includes a new application\ncookie.\n\nIf the application cookie is explicitly removed or expires, the session stops being sticky\nuntil a new application cookie is issued.\n\nFor more information, see [Application-Controlled Session Stickiness](https://amzn.to/2HFsyNz)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#create_app_cookie_stickiness_policy/3"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.create_app_cookie_stickiness_policy/3","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * policy_name (`String`) - The name of the policy being created. Policy names must consist\n  of alphanumeric characters and dashes (-). This name must be unique within the set of policies\n  for this load balancer\n\n  * cookie_name (`String`) - The name of the application cookie used for stickiness","ref":"ExAws.ElasticLoadBalancing.html#create_app_cookie_stickiness_policy/3-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.create_app_cookie_stickiness_policy/3","doc":"iex> ExAws.ElasticLoadBalancing.create_app_cookie_stickiness_policy(\"mylb\", \"my-app-sticky-policy\", \"my-cookie\")\n    %ExAws.Operation.Query{\n      action: :create_app_cookie_stickiness_policy,\n      params: %{\n        \"Action\" => \"CreateAppCookieStickinessPolicy\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"PolicyName\" => \"my-app-sticky-policy\",\n        \"CookieName\" => \"my-cookie\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#create_app_cookie_stickiness_policy/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.create_lb_cookie_stickiness_policy/3","doc":"Generates a stickiness policy with sticky session lifetimes controlled\nby the lifetime of the browser (user-agent) or a specified expiration period\n\nThis policy can be associated only with HTTP/HTTPS listeners.\n\nWhen a load balancer implements this policy, the load balancer uses a special\ncookie to track the instance for each request. When the load balancer receives\na request, it first checks to see if this cookie is present in the request. If\nso, the load balancer sends the request to the application server specified in\nthe cookie. If not, the load balancer sends the request to a server that is\nchosen based on the existing load-balancing algorithm.\n\nA cookie is inserted into the response for binding subsequent requests from the\nsame user to that server. The validity of the cookie is based on the cookie\nexpiration time, which is specified in the policy configuration.\n\nFor more information, see [Duration-Based Session Stickiness](https://amzn.to/2CzNbX9)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#create_lb_cookie_stickiness_policy/3"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.create_lb_cookie_stickiness_policy/3","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * policy_name (`String`) - The name of the policy being created. Policy names must consist\n  of alphanumeric characters and dashes (-). This name must be unique within the set of policies\n  for this load balancer\n\n  * cookie_expiration_period (`Integer`) - The time period, in seconds, after which the cookie\n  should be considered stale. If you do not specify this parameter, the default value is 0,\n  which indicates that the sticky session should last for the duration of the browser session","ref":"ExAws.ElasticLoadBalancing.html#create_lb_cookie_stickiness_policy/3-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.create_lb_cookie_stickiness_policy/3","doc":"iex> ExAws.ElasticLoadBalancing.create_lb_cookie_stickiness_policy(\"mylb\", \"my-app-sticky-policy\", 60)\n    %ExAws.Operation.Query{\n      action: :create_lb_cookie_stickiness_policy,\n      params: %{\n        \"Action\" => \"CreateLBCookieStickinessPolicy\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"PolicyName\" => \"my-app-sticky-policy\",\n        \"CookieExpirationPeriod\" => 60,\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#create_lb_cookie_stickiness_policy/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.create_load_balancer/3","doc":"Creates a Classic Load Balancer.\n\nYou can add listeners, security groups, subnets, and tags when you create your\nload balancer, or you can add them later using `create_load_balancer_listeners/2`,\n`apply_security_groups_to_load_balancer/2`, `attach_load_balancer_to_subnets/2`, and\n`add_tags/2`.\n\nTo describe your current load balancers, see `describe_load_balancers/1`. When you\nare finished with a load balancer, you can delete it using `delete_load_balancer/1`.\n\nYou can create up to 20 load balancers per region per account. You can request an\nincrease for the number of load balancers for your account. For more information,\nsee [Limits for Your Classic Load Balancer](https://amzn.to/2uxqzSW) in the\nClassic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer/3"},{"type":"function","title":"ExAws.ElasticLoadBalancing.create_load_balancer_listeners/2","doc":"Creates one or more listeners for the specified load balancer\n\nIf a listener with the specified port does not already exist, it is\ncreated; otherwise, the properties of the new listener must match the\nproperties of the existing listener.\n\nFor more information, see [Listeners for Your Classic Load Balancer](https://amzn.to/2CIUMCS)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_listeners/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.create_load_balancer_listeners/2","doc":"* load_balancer_name (`String`) - the load balancer name\n\n  * listeners (`List` of `t:listener/0`) - the listeners","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_listeners/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.create_load_balancer_listeners/2","doc":"iex> ExAws.ElasticLoadBalancing.create_load_balancer_listeners(\"mylb\",\n    ...> [%{protocol: \"https\", load_balancer_port: 443, instance_port: 443, instance_protocol: \"https\",\n    ...> ssl_certificate_id: \"arn:aws:iam::123456789012\"}])\n    %ExAws.Operation.Query{\n      action: :create_load_balancer_listeners,\n      params: %{\n        \"Action\" => \"CreateLoadBalancerListeners\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"Listeners.member.1.Protocol\" => \"https\",\n        \"Listeners.member.1.LoadBalancerPort\" => 443,\n        \"Listeners.member.1.InstancePort\" => 443,\n        \"Listeners.member.1.InstanceProtocol\" => \"https\",\n        \"Listeners.member.1.SSLCertificateId\" => \"arn:aws:iam::123456789012\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_listeners/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.create_load_balancer_policy/4","doc":"Creates a policy with the specified attributes for the specified load balancer\n\nPolicies are settings that are saved for your load balancer and that can be applied\nto the listener or the application server, depending on the policy type.","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_policy/4"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.create_load_balancer_policy/4","doc":"* load_balancer_name (`String`) - the load balancer name\n\n  * policy_name (`String`) - the name of the load balancer policy to be created. This\n  name must be unique within the set of policies for this load balancer\n\n  * policy_type_name (`String`) - the name of the base policy type. To get the list of\n  policy types, use `describe_load_balancer_policy_types/1`\n\n  * opts (`t:create_load_balancer_policy_opts/0`) - optional policy attributes","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_policy/4-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.create_load_balancer_policy/4","doc":"iex> ExAws.ElasticLoadBalancing.create_load_balancer_policy(\"mylb\",\n    ...> \"EnableProxyProtocol\", \"ProxyProtocolPolicyType\", policy_attributes: [%{attribute_name: \"ProxyProtocol\", attribute_value: true}])\n    %ExAws.Operation.Query{\n      action: :create_load_balancer_policy,\n      params: %{\n        \"Action\" => \"CreateLoadBalancerPolicy\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"PolicyAttributes.member.1.AttributeName\" => \"ProxyProtocol\",\n        \"PolicyAttributes.member.1.AttributeValue\" => true,\n        \"PolicyName\" => \"EnableProxyProtocol\",\n        \"PolicyTypeName\" => \"ProxyProtocolPolicyType\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#create_load_balancer_policy/4-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.delete_load_balancer/1","doc":"Deletes the specified load balancer\n\nIf you are attempting to recreate a load balancer, you must reconfigure all\nsettings. The DNS name associated with a deleted load balancer are no longer\nusable. The name and associated DNS record of the deleted load balancer no longer\nexist and traffic sent to any of its IP addresses is no longer delivered to your\ninstances.\n\nIf the load balancer does not exist or has already been deleted, the call to\n`delete_load_balancer/1` still succeeds.","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer/1"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.delete_load_balancer/1","doc":"* load_balancer_name (`String`) - the name of the load balancer","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer/1-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.delete_load_balancer/1","doc":"iex> ExAws.ElasticLoadBalancing.delete_load_balancer(\"mylb\")\n    %ExAws.Operation.Query{\n      action: :delete_load_balancer,\n      params: %{\n        \"Action\" => \"DeleteLoadBalancer\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.delete_load_balancer_listeners/2","doc":"Deletes the specified listeners from the specified load balancer","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_listeners/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.delete_load_balancer_listeners/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * ports (`List` of `Integer`) - The client port numbers of the listeners","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_listeners/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.delete_load_balancer_listeners/2","doc":"iex> ExAws.ElasticLoadBalancing.delete_load_balancer_listeners(\"mylb\", [8001, 8002])\n    %ExAws.Operation.Query{\n      action: :delete_load_balancer_listeners,\n      params: %{\n        \"Action\" => \"DeleteLoadBalancerListeners\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"LoadBalancerPorts.member.1\" => 8001,\n        \"LoadBalancerPorts.member.2\" => 8002,\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_listeners/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.delete_load_balancer_policy/2","doc":"Deletes the specified policy from the specified load balancer\n\nThis policy must not be enabled for any listeners.","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_policy/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.delete_load_balancer_policy/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * policy_name (`String`) - The name of the policy","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_policy/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.delete_load_balancer_policy/2","doc":"iex> ExAws.ElasticLoadBalancing.delete_load_balancer_policy(\"mylb\", \"my-policy\")\n    %ExAws.Operation.Query{\n      action: :delete_load_balancer_policy,\n      params: %{\n        \"Action\" => \"DeleteLoadBalancerPolicy\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"PolicyName\" => \"my-policy\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#delete_load_balancer_policy/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.deregister_instances_from_load_balancer/2","doc":"Deregisters the specified instances from the specified load balancer\n\nAfter the instance is deregistered, it no longer receives traffic from the load balancer.\n\nYou can use `describe_load_balancers/1` to verify that the instance is deregistered\nfrom the load balancer.\n\nFor more information, see [Register or De-Register EC2 Instances](https://amzn.to/2urqjVB)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#deregister_instances_from_load_balancer/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.deregister_instances_from_load_balancer/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * instances (`List` of `String`) - the  IDs of the instances","ref":"ExAws.ElasticLoadBalancing.html#deregister_instances_from_load_balancer/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.deregister_instances_from_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancing.deregister_instances_from_load_balancer(\"mylb\", [%{instance_id: \"i-12345678\"}])\n    %ExAws.Operation.Query{\n      action: :deregister_instances_from_load_balancer,\n      params: %{\n        \"Action\" => \"DeregisterInstancesFromLoadBalancer\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"Instances.member.1.InstanceId\" => \"i-12345678\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#deregister_instances_from_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_account_limits/1","doc":"Describes the current Elastic Load Balancing resource limits for your AWS account","ref":"ExAws.ElasticLoadBalancing.html#describe_account_limits/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.describe_account_limits/1","doc":"iex> ExAws.ElasticLoadBalancing.describe_account_limits()\n    %ExAws.Operation.Query{\n      action: :describe_account_limits,\n      params: %{\n        \"Action\" => \"DescribeAccountLimits\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#describe_account_limits/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_instance_health/2","doc":"Describes the state of the specified instances with respect to the specified load balancer\n\nIf no instances are specified, the call describes the state of all instances that are currently\nregistered with the load balancer. If instances are specified, their state is returned even if\nthey are no longer registered with the load balancer. The state of terminated instances is not\nreturned.","ref":"ExAws.ElasticLoadBalancing.html#describe_instance_health/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.describe_instance_health/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * opts (`t:describe_instance_health_opts/0`) - optionally provide a list of instance ids","ref":"ExAws.ElasticLoadBalancing.html#describe_instance_health/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.describe_instance_health/2","doc":"iex> ExAws.ElasticLoadBalancing.describe_instance_health(\"mylb\")\n    %ExAws.Operation.Query{\n      action: :describe_instance_health,\n      params: %{\n        \"Action\" => \"DescribeInstanceHealth\",\n        \"Version\" => \"2012-06-01\",\n        \"LoadBalancerName\" => \"mylb\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }\n\n    iex> ExAws.ElasticLoadBalancing.describe_instance_health(\"mylb\", [instances: [%{instance_id: \"i-12345678\"}]])\n    %ExAws.Operation.Query{\n      action: :describe_instance_health,\n      params: %{\n        \"Action\" => \"DescribeInstanceHealth\",\n        \"Version\" => \"2012-06-01\",\n        \"LoadBalancerName\" => \"mylb\",\n        \"Instances.member.1.InstanceId\" => \"i-12345678\",\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#describe_instance_health/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_load_balancer_attributes/1","doc":"Describes the attributes for the specified load balancer","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancer_attributes/1"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.describe_load_balancer_attributes/1","doc":"* load_balancer_name (`String`) - the name of the load balancer","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancer_attributes/1-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.describe_load_balancer_attributes/1","doc":"iex> ExAws.ElasticLoadBalancing.describe_load_balancer_attributes(\"mylb\")\n    %ExAws.Operation.Query{\n      action: :describe_load_balancer_attributes,\n      params: %{\n        \"Action\" => \"DescribeLoadBalancerAttributes\",\n        \"Version\" => \"2012-06-01\",\n        \"LoadBalancerName\" => \"mylb\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancer_attributes/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_load_balancer_policies/1","doc":"Describes the specified policies\n\nIf you specify a load balancer name, the action returns the descriptions of all\npolicies created for the load balancer. If you specify a policy name associated\nwith your load balancer, the action returns the description of that policy. If you\ndon't specify a load balancer name, the action returns descriptions of the specified\nsample policies, or descriptions of all sample policies. The names of the sample\npolicies have the ELBSample- prefix.","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancer_policies/1"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_load_balancer_policy_types/1","doc":"Describes the specified load balancer policy types or all load balancer policy types.\n\nThe description of each type indicates how it can be used. For example, some policies\ncan be used only with layer 7 listeners, some policies can be used only with layer 4\nlisteners, and some policies can be used only with your EC2 instances.\n\nYou can use `create_load_balancer_policy/4` to create a policy configuration for any of these\npolicy types. Then, depending on the policy type, use either\n`set_load_balancer_policies_of_listener/3` or\n`set_load_balancer_policies_for_backend_server/3` to set the policy.","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancer_policy_types/1"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_load_balancers/1","doc":"Describes the specified the load balancers\n\nIf no load balancers are specified, the call describes all of your load balancers.\n\nTo describe the attributes for a load balancer, use `describe_load_balancer_attributes/1`.\n\nThe options that can be passed into `describe_load_balancers/1` allow load_balancer_arns or names\n(there would not be a reason ordinarily to specify both). Elastic Load Balancing provides\ntwo versions of ARNS (one for Classic and one for Application Load Balancer). The syntax for\neach is below:\n\nClassic Load Balancer ARN Syntax:\n\n    arn:aws:elasticloadbalancing:region:account-id:loadbalancer/name\n\nApplication Load Balancer ARN Syntax:\n\n    arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id\n    arn:aws:elasticloadbalancing:region:account-id:listener/app/load-balancer-name/load-balancer-id/listener-id\n    arn:aws:elasticloadbalancing:region:account-id:listener-rule/app/load-balancer-name/load-balancer-id/listener-id/rule-id\n    arn:aws:elasticloadbalancing:region:account-id:targetgroup/target-group-name/target-group-id","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancers/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.describe_load_balancers/1","doc":"iex> ExAws.ElasticLoadBalancing.describe_load_balancers()\n    %ExAws.Operation.Query{\n      action: :describe_load_balancers,\n      params: %{\"Action\" => \"DescribeLoadBalancers\", \"Version\" => \"2012-06-01\"},\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#describe_load_balancers/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.describe_tags/1","doc":"Describes the tags associated with the specified load balancers","ref":"ExAws.ElasticLoadBalancing.html#describe_tags/1"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.describe_tags/1","doc":"* load_balancer_names (`List` of `String`) - the names of the load balancers. Minimum number of 1 item.\n  Maximum number of 20 items","ref":"ExAws.ElasticLoadBalancing.html#describe_tags/1-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.describe_tags/1","doc":"iex(1)> ExAws.ElasticLoadBalancing.describe_tags([\"load_balancer_name1\", \"load_balancer_name2\"])\n    %ExAws.Operation.Query{\n      action: :describe_tags,\n      params: %{\n        \"Action\" => \"DescribeTags\",\n        \"LoadBalancerNames.member.1\" => \"load_balancer_name1\",\n        \"LoadBalancerNames.member.2\" => \"load_balancer_name2\",\n        \"Version\" => \"2012-06-01\"\n      },\n      parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n      path: \"/\",\n      service: :elasticloadbalancing\n    }","ref":"ExAws.ElasticLoadBalancing.html#describe_tags/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.detach_load_balancer_from_subnets/2","doc":"Removes the specified subnets from the set of configured subnets for the load balancer.\n\nAfter a subnet is removed, all EC2 instances registered with the load balancer in the\nremoved subnet go into the OutOfService state. Then, the load balancer balances the\ntraffic among the remaining routable subnets.","ref":"ExAws.ElasticLoadBalancing.html#detach_load_balancer_from_subnets/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.detach_load_balancer_from_subnets/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * subnets (`List` of `String`) - the IDs of the subnets","ref":"ExAws.ElasticLoadBalancing.html#detach_load_balancer_from_subnets/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.detach_load_balancer_from_subnets/2","doc":"iex> ExAws.ElasticLoadBalancing.detach_load_balancer_from_subnets(\"mylb\", [\"subnet1\"])\n      %ExAws.Operation.Query{\n        action: :detach_load_balancer_from_subnets,\n        params: %{\n          \"Action\" => \"DetachLoadBalancerFromSubnets\",\n          \"LoadBalancerName\" => \"mylb\",\n          \"Subnets.member.1\" => \"subnet1\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#detach_load_balancer_from_subnets/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.disable_availability_zones_for_load_balancer/2","doc":"Removes the specified Availability Zones from the set of Availability Zones\nfor the specified load balancer in EC2-Classic or a default VPC.\n\nFor load balancers in a non-default VPC, use `detach_load_balancer_from_subnets/2`.\n\nThere must be at least one Availability Zone registered with a load balancer at\nall times. After an Availability Zone is removed, all instances registered with\nthe load balancer that are in the removed Availability Zone go into the OutOfService\nstate. Then, the load balancer attempts to equally balance the traffic among its\nremaining Availability Zones.\n\nFor more information, see [Add or Remove Availability Zones](https://amzn.to/2WtKE8q)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#disable_availability_zones_for_load_balancer/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.disable_availability_zones_for_load_balancer/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * availability_zones (`List` of `String`) - The Availability Zones. These must be in\n  the same region as the load balancer.","ref":"ExAws.ElasticLoadBalancing.html#disable_availability_zones_for_load_balancer/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.disable_availability_zones_for_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancing.disable_availability_zones_for_load_balancer(\"mylb\", [\"us-east-1c\"])\n      %ExAws.Operation.Query{\n        action: :disable_availability_zones_for_load_balancer,\n        params: %{\n          \"Action\" => \"DisableAvailabilityZonesForLoadBalancer\",\n          \"LoadBalancerName\" => \"mylb\",\n          \"AvailabilityZones.member.1\" => \"us-east-1c\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#disable_availability_zones_for_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.enable_availability_zones_for_load_balancer/2","doc":"Adds the specified Availability Zones to the set of Availability Zones for the specified\nload balancer in EC2-Classic or a default VPC.\n\nFor load balancers in a non-default VPC, use `attach_load_balancer_to_subnets/2`.\n\nThe load balancer evenly distributes requests across all its registered Availability Zones\nthat contain instances. For more information, see Add or Remove Availability Zones\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#enable_availability_zones_for_load_balancer/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.enable_availability_zones_for_load_balancer/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * availability_zones (`List` of `String`) - The Availability Zones. These must be in\n  the same region as the load balancer.","ref":"ExAws.ElasticLoadBalancing.html#enable_availability_zones_for_load_balancer/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.enable_availability_zones_for_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancing.enable_availability_zones_for_load_balancer(\"mylb\", [\"us-east-1c\"])\n      %ExAws.Operation.Query{\n        action: :enable_availability_zones_for_load_balancer,\n        params: %{\n          \"Action\" => \"EnableAvailabilityZonesForLoadBalancer\",\n          \"LoadBalancerName\" => \"mylb\",\n          \"AvailabilityZones.member.1\" => \"us-east-1c\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#enable_availability_zones_for_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.modify_load_balancer_attributes/2","doc":"Modifies the attributes of the specified load balancer.\n\nYou can modify the load balancer attributes, such as AccessLogs, ConnectionDraining,\nand CrossZoneLoadBalancing by either enabling or disabling them. Or, you can modify\nthe load balancer attribute ConnectionSettings by specifying an idle connection\ntimeout value for your load balancer.\n\nFor more information, see the following in the Classic Load Balancers Guide:\n\n* [Cross-Zone Load Balancing](https://amzn.to/2XhXnwe)\n* [Connection Draining](https://amzn.to/2JLr9af)\n* [Access Logs](https://amzn.to/2RhLiD9)\n* [Idle Connection Timeout](https://amzn.to/2U0jGZu)","ref":"ExAws.ElasticLoadBalancing.html#modify_load_balancer_attributes/2"},{"type":"function","title":"ExAws.ElasticLoadBalancing.register_instances_with_load_balancer/2","doc":"Adds the specified instances to the specified load balancer.\n\nThe instance must be a running instance in the same network as the load balancer\n(EC2-Classic or the same VPC). If you have EC2-Classic instances and a load balancer\nin a VPC with ClassicLink enabled, you can link the EC2-Classic instances to that\nVPC and then register the linked EC2-Classic instances with the load balancer in the VPC.\n\nNote that `register_instances_with_load_balancer/2` completes when the request has been registered.\nInstance registration takes a little time to complete. To check the state of the registered\ninstances, use `describe_load_balancers/1` or `describe_instance_health/2`.\n\nAfter the instance is registered, it starts receiving traffic and requests from the load\nbalancer. Any instance that is not in one of the Availability Zones registered for the load\nbalancer is moved to the OutOfService state. If an Availability Zone is added to the load\nbalancer later, any instances registered with the load balancer move to the InService state.\n\nTo deregister instances from a load balancer, use `deregister_instances_from_load_balancer/2`.\n\nFor more information, see [Register or De-Register EC2 Instances](https://amzn.to/2urqjVB)\nin the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#register_instances_with_load_balancer/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.register_instances_with_load_balancer/2","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * instances (`List` of `String`) - the IDs of the instances.","ref":"ExAws.ElasticLoadBalancing.html#register_instances_with_load_balancer/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.register_instances_with_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancing.register_instances_with_load_balancer(\"mylb\", [%{instance_id: \"i-12345678\"}])\n      %ExAws.Operation.Query{\n        action: :register_instances_with_load_balancer,\n        params: %{\n          \"Action\" => \"RegisterInstancesWithLoadBalancer\",\n          \"LoadBalancerName\" => \"mylb\",\n          \"Instances.member.1.InstanceId\" => \"i-12345678\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#register_instances_with_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.remove_tags/2","doc":"Removes one or more tags from the specified load balancer.","ref":"ExAws.ElasticLoadBalancing.html#remove_tags/2"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.remove_tags/2","doc":"* load_balancer_names (`List` of `String`) - the name of the load balancer. You can\n  specify a maximum of one load balancer name\n\n  * tag_keys (`List` of `t:tag_key_only/0`) - the keys for the tags to remove","ref":"ExAws.ElasticLoadBalancing.html#remove_tags/2-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.remove_tags/2","doc":"iex> ExAws.ElasticLoadBalancing.remove_tags([\"mylb\"], [%{key: \"department\"}, %{key: \"project\"}])\n      %ExAws.Operation.Query{\n        action: :remove_tags,\n        params: %{\n          \"Action\" => \"RemoveTags\",\n          \"LoadBalancerNames.member.1\" => \"mylb\",\n          \"Tags.member.1.Key\" => \"department\",\n          \"Tags.member.2.Key\" => \"project\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#remove_tags/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.set_load_balancer_listener_ssl_certificate/3","doc":"Sets the certificate that terminates the specified listener's SSL connections\n\nThe specified certificate replaces any prior certificate that was used on the\nsame load balancer and port.\n\nFor more information about updating your SSL certificate, see [Replace the SSL\nCertificate for Your Load Balancer](https://amzn.to/2HHSs3p) in the Classic\nLoad Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_listener_ssl_certificate/3"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.set_load_balancer_listener_ssl_certificate/3","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * ssl_certificate_id (`String`) - the Amazon Resource Name (ARN) of the SSL certificate\n\n  * load_balancer_port (`Integer`) - the port that uses the specified SSL certificate","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_listener_ssl_certificate/3-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.set_load_balancer_listener_ssl_certificate/3","doc":"iex> ExAws.ElasticLoadBalancing.set_load_balancer_listener_ssl_certificate(\"mylb\", \"arn:aws:iam::123456789012\", 443)\n      %ExAws.Operation.Query{\n        action: :set_load_balancer_listener_ssl_certificate,\n        params: %{\n          \"Action\" => \"SetLoadBalancerListenerSSLCertificate\",\n          \"LoadBalancerName\" => \"mylb\",\n          \"LoadBalancerPort\" => 443,\n          \"SSLCertificateId\" => \"arn:aws:iam::123456789012\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_listener_ssl_certificate/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.set_load_balancer_policies_for_backend_server/3","doc":"Replaces the set of policies associated with the specified port on which the\nEC2 instance is listening with a new set of policies\n\nAt this time, only the back-end server authentication policy type can be applied\nto the instance ports; this policy type is composed of multiple public key policies.\n\nEach time you use `set_load_balancer_policies_for_backend_server/3` to enable the policies, use\nthe PolicyNames parameter to list the policies that you want to enable.\n\nYou can use `describe_load_balancers/1` or `describe_load_balancer_policies/1` to verify that the\npolicy is associated with the EC2 instance.\n\nFor more information about enabling back-end instance authentication, see\n[Configure Back-end Instance Authentication](https://amzn.to/2TDGppd) in the Classic\nLoad Balancers Guide. For more information about Proxy Protocol, see [Configure Proxy\nProtocol Support](https://amzn.to/2HHelQd) in the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_for_backend_server/3"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.set_load_balancer_policies_for_backend_server/3","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * policy_names (`List` of `String`) - the names of the policies. If the list is empty,\n  then all current polices are removed from the EC2 instance\n\n  * instance_port (`Integer`) - the port number associated with the EC2 instance","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_for_backend_server/3-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.set_load_balancer_policies_for_backend_server/3","doc":"iex> ExAws.ElasticLoadBalancing.set_load_balancer_policies_for_backend_server(\"mylb\", [\"EnableProxyProtocol\", \"my-policy2\"], 80)\n      %ExAws.Operation.Query{\n        action: :set_load_balancer_policies_for_backend_server,\n        params: %{\n          \"Action\" => \"SetLoadBalancerPoliciesForBackendServer\",\n          \"InstancePort\" => 80,\n          \"LoadBalancerName\" => \"mylb\",\n          \"PolicyNames.member.1\" => \"EnableProxyProtocol\",\n          \"PolicyNames.member.2\" => \"my-policy2\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_for_backend_server/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancing.set_load_balancer_policies_of_listener/3","doc":"Replaces the current set of policies for the specified load balancer port with the specified set of policies.\n\nTo enable back-end server authentication, use `set_load_balancer_policies_for_backend_server/3`.\n\nFor more information about setting policies, see [Update the SSL Negotiation Configuration](https://amzn.to/2WuPGlj),\n[Duration-Based Session Stickiness](https://amzn.to/2CzNbX9), and [Application-Controlled Session\nStickiness](https://amzn.to/2HFsyNz) in the Classic Load Balancers Guide.","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_of_listener/3"},{"type":"function","title":"Parameters: - ExAws.ElasticLoadBalancing.set_load_balancer_policies_of_listener/3","doc":"* load_balancer_name (`String`) - the name of the load balancer\n\n  * policy_names (`List` of `String`) - the names of the policies. If the list is empty,\n  then all current polices are removed from the EC2 instance\n\n  * load_balancer_port (`Integer`) - the external port of the load balancer","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_of_listener/3-parameters"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancing.set_load_balancer_policies_of_listener/3","doc":"iex> ExAws.ElasticLoadBalancing.set_load_balancer_policies_of_listener(\"mylb\", [\"my-SSLNegotiation-policy\"], 443)\n      %ExAws.Operation.Query{\n        action: :set_load_balancer_policies_of_listener,\n        params: %{\n          \"Action\" => \"SetLoadBalancerPoliciesOfListener\",\n          \"LoadBalancerPort\" => 443,\n          \"LoadBalancerName\" => \"mylb\",\n          \"PolicyNames.member.1\" => \"my-SSLNegotiation-policy\",\n          \"Version\" => \"2012-06-01\"\n        },\n        parser: &ExAws.ElasticLoadBalancing.Parsers.parse/2,\n        path: \"/\",\n        service: :elasticloadbalancing\n      }","ref":"ExAws.ElasticLoadBalancing.html#set_load_balancer_policies_of_listener/3-examples"},{"type":"type","title":"ExAws.ElasticLoadBalancing.create_load_balancer_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:create_load_balancer_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.create_load_balancer_policy_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:create_load_balancer_policy_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.describe_account_limits_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:describe_account_limits_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.describe_instance_health_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:describe_instance_health_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.describe_load_balancer_policies_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:describe_load_balancer_policies_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.describe_load_balancer_policy_types_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:describe_load_balancer_policy_types_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.describe_load_balancers_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:describe_load_balancers_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.health_check/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:health_check/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.instance/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:instance/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.listener/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:listener/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.load_balancer_attribute/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:load_balancer_attribute/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.policy_attribute/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:policy_attribute/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.tag/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:tag/0"},{"type":"type","title":"ExAws.ElasticLoadBalancing.tag_key_only/0","doc":"","ref":"ExAws.ElasticLoadBalancing.html#t:tag_key_only/0"},{"type":"module","title":"ExAws.ElasticLoadBalancingV2","doc":"Operations on AWS ELB (Elastic Load Balancing) V2 API\n\nAWS Elastic Load Balancing supports three types of load balancers: Application\nLoad Balancers (ALB), Network Load Balancers (NLB), and Classic Load Balancers. You can\nselect a load balancer based on your application needs. This API covers the\nALB and NLB. Classic Load Balancers are covered by the `ExAws.ElasticLoadBalancing` module.\n\nMore information:\n* [Elastic Load Balancing User Guide][User_Guide]\n* [Elastic Load Balancing API][API_Doc]\n* [Amazon Resource Names (ARNs)][ARN_Doc]\n\n[User_Guide]: http://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/\n[API_Doc]: http://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/\n[ARN_Doc]: http://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html","ref":"ExAws.ElasticLoadBalancingV2.html"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.add_listener_certificates/3","doc":"Adds the specified certificate to the specified secure listener.\n\nIf the certificate was already added, the call is successful but the certificate\nis not added again.\n\nTo list the certificates for your listener, use `describe_listener_certificates/1`.\nTo remove certificates from your listener, use `remove_listener_certificates/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#add_listener_certificates/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.add_listener_certificates/3","doc":"iex> ExAws.ElasticLoadBalancingV2.add_listener_certificates(\n      ...> \"listener_arn\",\n      ...>  [%{certificate_arn: \"certificate1_arn\", is_default: true},\n      ...>   %{certificate_arn: \"certificate2_arn\"}])\n      %ExAws.Operation.Query{action: :add_listener_certificates,\n      params: %{\"Action\" => \"AddListenerCertificates\",\n      \"Certificates.member.1.CertificateArn\" => \"certificate1_arn\",\n      \"Certificates.member.1.IsDefault\" => true,\n      \"Certificates.member.2.CertificateArn\" => \"certificate2_arn\",\n      \"ListenerArn\" => \"listener_arn\", \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#add_listener_certificates/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.add_tags/3","doc":"Adds the specified tags to the specified Elastic Load Balancing resource.\n\nYou can tag your Application Load Balancers, Network Load Balancers, and your target groups.\n\nEach tag consists of a key and an optional value. If a resource already has a tag with the same\nkey, `add_tags/1` updates its value.\n\nTo list the current tags for your resources, use `describe_tags/1`. To remove tags from\nyour resources, use `remove_tags/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#add_tags/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.add_tags/3","doc":"iex> ExAws.ElasticLoadBalancingV2.add_tags([\"resource_arn1\", \"resource_arn2\"], [%{key: \"hello\", value: \"test\"}])\n      %ExAws.Operation.Query{action: :add_tags,\n      params: %{\"Action\" => \"AddTags\",\n      \"ResourceArns.member.1\" => \"resource_arn1\",\n      \"ResourceArns.member.2\" => \"resource_arn2\",\n      \"Tags.member.1.Key\" => \"hello\", \"Tags.member.1.Value\" => \"test\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n      iex> ExAws.ElasticLoadBalancingV2.add_tags([\"resource_arn1\", \"resource_arn2\"], [hello: \"test\"])\n      %ExAws.Operation.Query{action: :add_tags,\n      params: %{\"Action\" => \"AddTags\",\n      \"ResourceArns.member.1\" => \"resource_arn1\",\n      \"ResourceArns.member.2\" => \"resource_arn2\",\n      \"Tags.member.1.Key\" => \"hello\", \"Tags.member.1.Value\" => \"test\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n      iex> ExAws.ElasticLoadBalancingV2.add_tags([\"resource_arn1\", \"resource_arn2\"], [{:hello, \"test\"}])\n      %ExAws.Operation.Query{action: :add_tags,\n      params: %{\"Action\" => \"AddTags\",\n      \"ResourceArns.member.1\" => \"resource_arn1\",\n      \"ResourceArns.member.2\" => \"resource_arn2\",\n      \"Tags.member.1.Key\" => \"hello\", \"Tags.member.1.Value\" => \"test\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#add_tags/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.create_listener/5","doc":"Creates a listener for the specified Application Load Balancer\nor Network Load Balancer.\n\nYou can create up to 10 listeners per load balancer.\n\nTo update a listener, use `modify_listener/1`. When you are finished with a\nlistener, you can delete it using `delete_listener/1`. If you are finished\nwith both the listener and the load balancer, you can delete them both\nusing `delete_load_balancer/1`.\n\nMore information:\n* [Listeners for Your Application Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html)\nin the *Application Load Balancers Guide*\n* [Listeners for Your Network Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-listeners.html)\nin the *Network Load Balancers Guide*","ref":"ExAws.ElasticLoadBalancingV2.html#create_listener/5"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.create_listener/5","doc":"iex> ExAws.ElasticLoadBalancingV2.create_listener(\n      ...> \"load_balancer_arn\",\n      ...> \"HTTP\", 80, [%{type: \"forward\", target_group_arn: \"target_arn\"}])\n      %ExAws.Operation.Query{action: :create_listener,\n      params: %{\"Action\" => \"CreateListener\",\n      \"DefaultActions.member.1.TargetGroupArn\" => \"target_arn\",\n      \"DefaultActions.member.1.Type\" => \"forward\",\n      \"LoadBalancerArn\" => \"load_balancer_arn\", \"Port\" => 80, \"Protocol\" => \"HTTP\",\n      \"Version\" => \"2015-12-01\"}, parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\",\n      service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#create_listener/5-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.create_load_balancer/2","doc":"Creates an Application Load Balancer or a Network Load Balancer.\n\nWhen you create a load balancer, you can specify security groups, subnets,\nIP address type, and tags. Otherwise, you could do so later using set_security_groups,\nset_subnets, set_ip_address_type, and add_tags.\n\nTo create listeners for your load balancer, use `create_listener/1`. To describe your\ncurrent load balancers, see `describe_load_balancer/1`. When you are finished with a\nload balancer, you can delete it using `delete_load_balancer/1`.\n\nYou can create up to 20 load balancers per region per account. You can request an\nincrease for the number of load balancers for your account.\n\nMore information:\n* [Limits for Your Application Load Balancer](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html)\nin the *Application Load Balancers Guide*\n* [Limits for Your Network Load Balancer](http://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-limits.html)\nin the *Network Load Balancers Guide*","ref":"ExAws.ElasticLoadBalancingV2.html#create_load_balancer/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.create_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancingV2.create_load_balancer(\"Loader\")\n      %ExAws.Operation.Query{action: :create_load_balancer,\n      params: %{\"Action\" => \"CreateLoadBalancer\",\n      \"Name\" => \"Loader\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n      iex> ExAws.ElasticLoadBalancingV2.create_load_balancer(\"Loader\",\n      ...> [schema: \"internet-facing\",\n      ...> subnet_mappings: [%{subnet_id: \"1.2.3.4\", allocation_id: \"i2234342\"}],\n      ...> subnets: [\"1.2.3.4\", \"5.6.7.8\"],\n      ...> security_groups: [\"Secure123\", \"Secure456\"],\n      ...> type: \"application\", ip_address_type: \"ipv4\"])\n      %ExAws.Operation.Query{action: :create_load_balancer,\n      params: %{\"Action\" => \"CreateLoadBalancer\", \"IpAddressType\" => \"ipv4\",\n      \"Name\" => \"Loader\", \"Schema\" => \"internet-facing\",\n      \"SecurityGroups.member.1\" => \"Secure123\",\n      \"SecurityGroups.member.2\" => \"Secure456\",\n      \"SubnetMappings.member.1.AllocationId\" => \"i2234342\",\n      \"SubnetMappings.member.1.SubnetId\" => \"1.2.3.4\",\n      \"Subnets.member.1\" => \"1.2.3.4\", \"Subnets.member.2\" => \"5.6.7.8\",\n      \"Type\" => \"application\", \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#create_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.create_rule/5","doc":"Creates a rule for the specified listener.\n\nThe listener must be associated with an Application Load Balancer. Rules are\nevaluated in priority order, from the lowest value to the highest value. When\nthe condition for a rule is met, the specified action is taken. If no conditions\nare met, the action for the default rule is taken.\n\nMore information:\n* [Listener Rules](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html#listener-rules)\n*Application Load Balancers Guide*\n\nTo view your current rules, use `describe_rules/1`. To update a rule, use\n`modify_rule/1`. To set the priorities of your rules, use `set_rule_priorities/1`.\nTo delete a rule, use `delete_rule/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#create_rule/5"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.create_target_group/3","doc":"Creates a target group.\n\nTo register targets with the target group, use `register_targets/1`. To\nupdate the health check settings for the target group, use\n`modify_target_group/1`. To monitor the health of targets in the target group,\nuse `describe_target_health/1`. To route traffic to the targets in a target group,\nspecify the target group in an action using `create_listener/1` or `create_rule/1`.\nTo delete a target group, use `delete_target_group/1`.\n\nMore information:\n* [Target Groups for Your Application Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html)\nin the *Application Load Balancers Guide*\n* [Target Groups for Your Network Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html)\nin the *Network Load Balancers Guide*.","ref":"ExAws.ElasticLoadBalancingV2.html#create_target_group/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.create_target_group/3","doc":"iex> ExAws.ElasticLoadBalancingV2.create_target_group(\"target_group_name\", \"vpc_id\")\n    %ExAws.Operation.Query{action: :create_target_group,\n    params: %{\"Action\" => \"CreateTargetGroup\", \"Name\" => \"target_group_name\",\n      \"Version\" => \"2015-12-01\", \"VpcId\" => \"vpc_id\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#create_target_group/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.delete_listener/2","doc":"Deletes the specified listener.\n\nAlternatively, your listener is deleted when you delete the load balancer\nit is attached to using `delete_load_balancer/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#delete_listener/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.delete_listener/2","doc":"iex> ExAws.ElasticLoadBalancingV2.delete_listener(\"listener_arn\")\n      %ExAws.Operation.Query{action: :delete_listener,\n      params: %{\"Action\" => \"DeleteListener\",\n      \"ListenerArn\" => \"listener_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#delete_listener/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.delete_load_balancer/2","doc":"Deletes the specified Application Load Balancer or Network Load Balancer\nand its attached listeners.\n\nYou can't delete a load balancer if deletion protection is enabled.\nIf the load balancer does not exist or has already been deleted,\nthe call succeeds.\n\nDeleting a load balancer does not affect its registered targets. For\nexample, your EC2 instances continue to run and are still registered\nto their target groups. If you no longer need these EC2 instances,\nyou can stop or terminate them.","ref":"ExAws.ElasticLoadBalancingV2.html#delete_load_balancer/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.delete_load_balancer/2","doc":"iex> ExAws.ElasticLoadBalancingV2.delete_load_balancer(\"load_balancer_arn\")\n      %ExAws.Operation.Query{action: :delete_load_balancer,\n      params: %{\"Action\" => \"DeleteLoadBalancer\",\n      \"LoadBalancerArn\" => \"load_balancer_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#delete_load_balancer/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.delete_rule/2","doc":"Deletes the specified rule.","ref":"ExAws.ElasticLoadBalancingV2.html#delete_rule/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.delete_rule/2","doc":"iex> ExAws.ElasticLoadBalancingV2.delete_rule(\"rule_arn\")\n      %ExAws.Operation.Query{action: :delete_rule,\n      params: %{\"Action\" => \"DeleteRule\",\n      \"RuleArn\" => \"rule_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#delete_rule/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.delete_target_group/2","doc":"Deletes the specified target group.\n\nYou can delete a target group if it is not referenced by any\nactions. Deleting a target group also deletes any associated\nhealth checks.","ref":"ExAws.ElasticLoadBalancingV2.html#delete_target_group/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.delete_target_group/2","doc":"iex> ExAws.ElasticLoadBalancingV2.delete_target_group(\"target_group_arn\")\n      %ExAws.Operation.Query{action: :delete_target_group,\n      params: %{\"Action\" => \"DeleteTargetGroup\",\n      \"TargetGroupArn\" => \"target_group_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#delete_target_group/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.deregister_targets/3","doc":"Deregisters the specified targets from the specified target group.\n\nAfter the targets are deregistered, they no longer receive traffic\nfrom the load balancer.","ref":"ExAws.ElasticLoadBalancingV2.html#deregister_targets/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.deregister_targets/3","doc":"iex> ExAws.ElasticLoadBalancingV2.deregister_targets(\"target_group_arn\",\n      ...> [%{id: \"test\", port: 8080, availability_zone: \"us-east-1\"},\n      ...>  %{id: \"test2\", port: 8088, availability_zone: \"us-east-1\"}])\n      %ExAws.Operation.Query{action: :deregister_targets,\n      params: %{\"Action\" => \"DeregisterTargets\",\n      \"TargetGroupArn\" => \"target_group_arn\",\n      \"Targets.member.1.AvailabilityZone\" => \"us-east-1\",\n      \"Targets.member.1.Id\" => \"test\", \"Targets.member.1.Port\" => 8080,\n      \"Targets.member.2.AvailabilityZone\" => \"us-east-1\",\n      \"Targets.member.2.Id\" => \"test2\", \"Targets.member.2.Port\" => 8088,\n      \"Version\" => \"2015-12-01\"}, parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\",\n      service: :elasticloadbalancing}\n\n      iex> ExAws.ElasticLoadBalancingV2.deregister_targets(\"target_group_arn\", [%{id: \"i-0f76fade435676abd\"}])\n      %ExAws.Operation.Query{action: :deregister_targets,\n      params: %{\"Action\" => \"DeregisterTargets\",\n        \"TargetGroupArn\" => \"target_group_arn\",\n        \"Targets.member.1.Id\" => \"i-0f76fade435676abd\", \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#deregister_targets/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_account_limits/1","doc":"Describes the current Elastic Load Balancing resource limits\nfor your AWS account.\n\nMore information:\n* [Limits for Your Application Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html)\nin the *Application Load Balancer Guide*\n* [Limits for Your Network Load Balancers](http://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-limits.html)\nin the *Network Load Balancers Guide*.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_account_limits/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_account_limits/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_account_limits()\n      %ExAws.Operation.Query{action: :describe_account_limits,\n      params: %{\"Action\" => \"DescribeAccountLimits\", \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_account_limits/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_listener_certificates/2","doc":"Describes the certificates for the specified secure listener.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_listener_certificates/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_listener_certificates/2","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_listener_certificates(\"listener_arn\");\n      %ExAws.Operation.Query{action: :describe_listener_certificates,\n      params: %{\"Action\" => \"DescribeListenerCertificates\",\n      \"ListenerArn\" => \"listener_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_listener_certificates/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_listeners/1","doc":"Describes the specified listeners or the listeners for the\nspecified Application Load Balancer or Network Load Balancer.\n\nYou must specify either a load balancer or one or more listeners.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_listeners/1"},{"type":"function","title":"Example - ExAws.ElasticLoadBalancingV2.describe_listeners/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_listeners()\n    %ExAws.Operation.Query{action: :describe_listeners,\n    params: %{\"Action\" => \"DescribeListeners\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_listeners/1-example"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_load_balancer_attributes/2","doc":"Describes the attributes for the specified Application Load\nBalancer or Network Load Balancer.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_load_balancer_attributes/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_load_balancer_attributes/2","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_load_balancer_attributes(\n      ...> \"load_balancer_arn\")\n      %ExAws.Operation.Query{action: :describe_load_balancer_attributes,\n      params: %{\"Action\" => \"DescribeLoadBalancerAttributes\",\n      \"LoadBalancerArn\" => \"load_balancer_arn\",\n      \"Version\" => \"2015-12-01\"},\n      parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_load_balancer_attributes/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_load_balancers/1","doc":"Describes the specified load balancers or all of your\nload balancers.\n\nTo describe the listeners for a load balancer, use `describe_listeners/1`.\nTo describe the attributes for a load balancer, use `describe_load_balancer_attributes/1`.\n\nThe options that can be passed into `describe_load_balancers/1` allow load_balancer_arns or names\n(there would not be a reason ordinarily to specify both). Elastic Load Balancing provides\ntwo versions of ARNS (one for Classic and one for Application Load Balancer). The syntax for\neach is below:\n\nClassic Load Balancer ARN Syntax:\n\n    arn:aws:elasticloadbalancing:region:account-id:loadbalancer/name\n\nApplication Load Balancer ARN Syntax:\n\n    arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id\n    arn:aws:elasticloadbalancing:region:account-id:listener/app/load-balancer-name/load-balancer-id/listener-id\n    arn:aws:elasticloadbalancing:region:account-id:listener-rule/app/load-balancer-name/load-balancer-id/listener-id/rule-id\n    arn:aws:elasticloadbalancing:region:account-id:targetgroup/target-group-name/target-group-id","ref":"ExAws.ElasticLoadBalancingV2.html#describe_load_balancers/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_load_balancers/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_load_balancers\n    %ExAws.Operation.Query{action: :describe_load_balancers,\n    params: %{\"Action\" => \"DescribeLoadBalancers\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_load_balancers/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_rules/1","doc":"Describes the specified rules or the rules for the specified listener.\n\nYou must specify either a listener or one or more rules.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_rules/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_rules/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_rules()\n    %ExAws.Operation.Query{action: :describe_rules,\n    params: %{\"Action\" => \"DescribeRules\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n    iex> ExAws.ElasticLoadBalancingV2.describe_rules([listener_arn: \"listener_arn\", rule_arns: [\"rule_arns\"]])\n    %ExAws.Operation.Query{action: :describe_rules,\n    params: %{\"Action\" => \"DescribeRules\", \"ListenerArn\" => \"listener_arn\",\n    \"RuleArns.member.1\" => \"rule_arns\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_rules/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_ssl_policies/1","doc":"Describes the specified policies or all policies used for SSL negotiation.\n\nMore information:\n* [Security Policies](http://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html#describe-ssl-policies)\nin the *Application Load Balancers Guide*.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_ssl_policies/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_ssl_policies/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_ssl_policies()\n     %ExAws.Operation.Query{action: :describe_ssl_policies,\n     params: %{\"Action\" => \"DescribeSslPolicies\", \"Version\" => \"2015-12-01\"},\n     parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n     iex> ExAws.ElasticLoadBalancingV2.describe_ssl_policies([ssl_policy_names: [\"policy1\", \"policy2\"]])\n     %ExAws.Operation.Query{action: :describe_ssl_policies,\n     params: %{\"Action\" => \"DescribeSslPolicies\", \"SslPolicyNames.1\" => \"policy1\",\n     \"SslPolicyNames.2\" => \"policy2\", \"Version\" => \"2015-12-01\"},\n     parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_ssl_policies/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_tags/2","doc":"Describes the tags for the specified resources.\n\nYou can describe the tags for one or more Application Load Balancers,\nNetwork Load Balancers, and target groups.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_tags/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_tags/2","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_tags([\"resource_arn1\", \"resource_arn2\"])\n    %ExAws.Operation.Query{action: :describe_tags,\n    params: %{\"Action\" => \"DescribeTags\", \"ResourceArns.member.1\" => \"resource_arn1\",\n    \"ResourceArns.member.2\" => \"resource_arn2\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_tags/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_target_group_attributes/2","doc":"Describes the attributes for the specified target group.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_target_group_attributes/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_target_group_attributes/2","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_target_group_attributes([\"target_group_arn1\", \"target_group_arn2\"])\n    %ExAws.Operation.Query{action: :describe_target_group_attributes,\n    params: %{\"Action\" => \"DescribeTargetGroupAttributes\",\n    \"TargetGroupArn.1\" => \"target_group_arn1\",\n    \"TargetGroupArn.2\" => \"target_group_arn2\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_target_group_attributes/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_target_groups/1","doc":"Describes the specified target groups or all of your target groups.\n\n By default, all target groups are described. Alternatively, you can\n specify one of the following to filter the results: the ARN of the\n load balancer, the names of one or more target groups, or the ARNs\n of one or more target groups. To describe the targets for a\n target group, use `describe_target_health/1`. To describe the attributes\n of a target group, use `describe_target_group_attributes/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_target_groups/1"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.describe_target_groups/1","doc":"iex> ExAws.ElasticLoadBalancingV2.describe_target_groups()\n     %ExAws.Operation.Query{action: :describe_target_groups,\n     params: %{\"Action\" => \"DescribeTargetGroups\", \"Version\" => \"2015-12-01\"},\n     parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n     iex> ExAws.ElasticLoadBalancingV2.describe_target_groups([load_balancer_arn: \"load_balancer_arn\",\n     ...> target_group_arns: [\"target_group_arn1\", \"target_group_arn2\"]])\n     %ExAws.Operation.Query{action: :describe_target_groups,\n     params: %{\"Action\" => \"DescribeTargetGroups\",\n       \"LoadBalancerArn\" => \"load_balancer_arn\",\n       \"TargetGroupArns.member.1\" => \"target_group_arn1\",\n       \"TargetGroupArns.member.2\" => \"target_group_arn2\",\n       \"Version\" => \"2015-12-01\"}, parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\",\n     service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#describe_target_groups/1-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.describe_target_health/2","doc":"Describes the health of the specified targets or all of your targets.","ref":"ExAws.ElasticLoadBalancingV2.html#describe_target_health/2"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.modify_listener/2","doc":"Modifies the specified properties of the specified listener.\n\nAny properties that you do not specify retain their current values.\nHowever, changing the protocol from HTTPS to HTTP removes the security\npolicy and SSL certificate properties. If you change the protocol from\nHTTP to HTTPS, you must add the security policy and server certificate.","ref":"ExAws.ElasticLoadBalancingV2.html#modify_listener/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.modify_listener/2","doc":"iex> ExAws.ElasticLoadBalancingV2.modify_listener(\"listener_arn\")\n    %ExAws.Operation.Query{action: :modify_listener,\n    params: %{\"Action\" => \"ModifyListener\", \"ListenerArn\" => \"listener_arn\",\n    \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n    iex> ExAws.ElasticLoadBalancingV2.modify_listener(\"listener_arn\",\n    ...> [port: 80, protocol: \"HTTP\", certificates: [\"certificate1\", \"certificate2\"]])\n    %ExAws.Operation.Query{action: :modify_listener,\n    params: %{\"Action\" => \"ModifyListener\",\n      \"Certificates.member.1\" => \"certificate1\",\n      \"Certificates.member.2\" => \"certificate2\", \"ListenerArn\" => \"listener_arn\",\n      \"Port\" => 80, \"Protocol\" => \"HTTP\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#modify_listener/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.modify_load_balancer_attributes/3","doc":"Modifies the specified attributes of the specified Application Load Balancer\nor Network Load Balancer.\n\nIf any of the specified attributes can't be modified as requested, the call\nfails. Any existing attributes that you do not modify retain their current\nvalues.","ref":"ExAws.ElasticLoadBalancingV2.html#modify_load_balancer_attributes/3"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.modify_rule/2","doc":"Modifies the specified rule.\n\nAny existing properties that you do not modify retain their current values.\nTo modify the default action, use `modify_listener/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#modify_rule/2"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.modify_target_group/2","doc":"Modifies the health checks used when evaluating the health state of\nthe targets in the specified target group.\n\nTo monitor the health of the targets, use `describe_target_health/1`.\n\nExamples:\n\n    iex> ExAws.ElasticLoadBalancingV2.modify_target_group(\"target_group_arn\")\n    %ExAws.Operation.Query{action: :modify_target_group,\n    params: %{\"Action\" => \"ModifyTargetGroup\",\n      \"TargetGroupArn\" => \"target_group_arn\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}\n\n    iex> ExAws.ElasticLoadBalancingV2.modify_target_group(\"target_group_arn\",\n    ...> [heath_check_port: 8088, health_check_protocol: \"HTTP\", health_check_path: \"/\"])\n    %ExAws.Operation.Query{action: :modify_target_group,\n    params: %{\"Action\" => \"ModifyTargetGroup\", \"HealthCheckPath\" => \"/\",\n    \"HealthCheckProtocol\" => \"HTTP\", \"HeathCheckPort\" => 8088,\n    \"TargetGroupArn\" => \"target_group_arn\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#modify_target_group/2"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.modify_target_group_attributes/3","doc":"Modifies the specified attributes of the specified target group.","ref":"ExAws.ElasticLoadBalancingV2.html#modify_target_group_attributes/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.modify_target_group_attributes/3","doc":"iex> ExAws.ElasticLoadBalancingV2.modify_target_group_attributes(\"target_group_arn\",\n    ...> [{:hello, \"test\"}])\n    %ExAws.Operation.Query{action: :modify_target_group_attributes,\n    params: %{\"Action\" => \"ModifyTargetGroupAttributes\",\n    \"Attributes.member.1.Key\" => \"hello\", \"Attributes.member.1.Value\" => \"test\",\n    \"TargetGroupArn\" => \"target_group_arn\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#modify_target_group_attributes/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.register_targets/3","doc":"Registers the specified targets with the specified target group.\n\nYou can register targets by instance ID or by IP address. If the\ntarget is an EC2 instance, it must be in the `running` state when you\nregister it.\n\nBy default, the load balancer routes requests to registered targets using\nthe protocol and port for the target group. Alternatively, you can override\nthe port for a target when you register it. You can register each EC2\ninstance or IP address with the same target group multiple times using\ndifferent ports.\n\nWith a Network Load Balancer, you cannot register instances by instance ID\nif they have the following instance types: C1, CC1, CC2, CG1, CG2, CR1,\nCS1, G1, G2, HI1, HS1, M1, M2, M3, and T1. You can register instances of\nthese types by IP address.\n\nTo remove a target from a target group, use `deregister_targets/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#register_targets/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.register_targets/3","doc":"iex> ExAws.ElasticLoadBalancingV2.register_targets(\"target_group_arn\", [\"target1\", \"target2\"])\n    %ExAws.Operation.Query{action: :register_targets,\n    params: %{\"Action\" => \"RegisterTargets\",\n      \"TargetGroupArn\" => \"target_group_arn\", \"Targets.member.1\" => \"target1\",\n      \"Targets.member.2\" => \"target2\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#register_targets/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.remove_listener_certificates/3","doc":"Removes the specified certificate from the specified secure listener.\n\nYou can't remove the default certificate for a listener. To replace\nthe default certificate, call `modify_listener/1`. To list the certificates\nfor your listener, use `describe_listener_certificates/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#remove_listener_certificates/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.remove_listener_certificates/3","doc":"iex> ExAws.ElasticLoadBalancingV2.remove_listener_certificates(\"listener_arn\",\n    ...> [%{certificate_arn: \"certificate1_arn\", is_default: true}, %{certificate_arn: \"certificate2_arn\"}])\n    %ExAws.Operation.Query{action: :remove_listener_certificates,\n    params: %{\"Action\" => \"RemoveListenerCertificates\",\n    \"Certificates.member.1.CertificateArn\" => \"certificate1_arn\",\n    \"Certificates.member.1.IsDefault\" => true,\n    \"Certificates.member.2.CertificateArn\" => \"certificate2_arn\",\n    \"ListenerArn\" => \"listener_arn\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#remove_listener_certificates/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.remove_tags/3","doc":"Removes the specified tags from the specified Elastic Load Balancing\nresource.\n\nTo list the current tags for your resources, use `describe_tags/1`.","ref":"ExAws.ElasticLoadBalancingV2.html#remove_tags/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.remove_tags/3","doc":"iex> ExAws.ElasticLoadBalancingV2.remove_tags([\"resource_arn1\", \"resource_arn2\"], [\"tag1\", \"tag2\"])\n    %ExAws.Operation.Query{action: :remove_tags,\n    params: %{\"Action\" => \"RemoveTags\",\n    \"ResourceArns.member.1\" => \"resource_arn1\", \"ResourceArns.member.2\" => \"resource_arn2\",\n    \"TagsKeys.1\" => \"tag1\", \"TagsKeys.2\" => \"tag2\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#remove_tags/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.set_ip_address_type/3","doc":"Sets the type of IP addresses used by the subnets of the specified\nApplication Load Balancer or Network Load Balancer.\n\n*Note: Network Load Balancers must use `ipv4`*.","ref":"ExAws.ElasticLoadBalancingV2.html#set_ip_address_type/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.set_ip_address_type/3","doc":"iex> ExAws.ElasticLoadBalancingV2.set_ip_address_type(\"load_balancer_arn\", \"ipv4\")\n    %ExAws.Operation.Query{action: :set_ip_address_type,\n    params: %{\"Action\" => \"SetIpAddressType\", \"IpAddressType\" => \"ipv4\",\n    \"LoadBalancerArn\" => \"load_balancer_arn\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#set_ip_address_type/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.set_rule_priorities/2","doc":"Sets the priorities of the specified rules.\n\nYou can reorder the rules as long as there are no priority conflicts\nin the new order. Any existing rules that you do not specify retain\ntheir current priority.","ref":"ExAws.ElasticLoadBalancingV2.html#set_rule_priorities/2"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.set_rule_priorities/2","doc":"iex> ExAws.ElasticLoadBalancingV2.set_rule_priorities([1,2,3])\n    %ExAws.Operation.Query{action: :set_rule_priorities,\n    params: %{\"Action\" => \"SetRulePriorities\", \"RulePriorities.member.1\" => 1,\n    \"RulePriorities.member.2\" => 2, \"RulePriorities.member.3\" => 3,\n    \"Version\" => \"2015-12-01\"}, parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\",\n    service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#set_rule_priorities/2-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.set_security_groups/3","doc":"Associates the specified security groups with the specified Application\nLoad Balancer.\n\nThe specified security groups override the previously associated security\ngroups.\n\n*Note: You can't specify a security group for a Network Load Balancer*.","ref":"ExAws.ElasticLoadBalancingV2.html#set_security_groups/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.set_security_groups/3","doc":"iex>  ExAws.ElasticLoadBalancingV2.set_security_groups(\"load_balancer_arn\", [\"security_group1\", \"security_group2\"])\n    %ExAws.Operation.Query{action: :set_security_groups,\n    params: %{\"Action\" => \"SetSecurityGroups\",\n      \"LoadBalancerArn\" => \"load_balancer_arn\",\n      \"SecurityGroups.member.1\" => \"security_group1\",\n      \"SecurityGroups.member.2\" => \"security_group2\", \"Version\" => \"2015-12-01\"},\n    parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\", service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#set_security_groups/3-examples"},{"type":"function","title":"ExAws.ElasticLoadBalancingV2.set_subnets/3","doc":"Enables the Availability Zone for the specified subnets for the specified\nApplication Load Balancer.\n\nThe specified subnets replace the previously enabled subnets.\n\n*Note: You can't change the subnets for a Network Load Balancer*.","ref":"ExAws.ElasticLoadBalancingV2.html#set_subnets/3"},{"type":"function","title":"Examples: - ExAws.ElasticLoadBalancingV2.set_subnets/3","doc":"iex>  ExAws.ElasticLoadBalancingV2.set_subnets(\"load_balancer_arn\", [\"subnet1\", \"subnet2\"])\n    %ExAws.Operation.Query{action: :set_subnets,\n    params: %{\"Action\" => \"SetSubnets\", \"LoadBalancerArn\" => \"load_balancer_arn\",\n      \"Subnets.member.1\" => \"subnet1\", \"Subnets.member.2\" => \"subnet2\",\n      \"Version\" => \"2015-12-01\"}, parser: &ExAws.ElasticLoadBalancingV2.Parsers.parse/2, path: \"/\",\n    service: :elasticloadbalancing}","ref":"ExAws.ElasticLoadBalancingV2.html#set_subnets/3-examples"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.action/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:action/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.certificate/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:certificate/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.create_listener_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:create_listener_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.create_load_balancer_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:create_load_balancer_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.create_target_group_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:create_target_group_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_account_limits_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_account_limits_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_listener_certificates_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_listener_certificates_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_listeners_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_listeners_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_load_balancers_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_load_balancers_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_rules_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_rules_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_ssl_policies_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_ssl_policies_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_target_groups_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_target_groups_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.describe_target_health_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:describe_target_health_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.load_balancer_attribute/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:load_balancer_attribute/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.modify_listener_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:modify_listener_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.modify_rule_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:modify_rule_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.modify_target_group_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:modify_target_group_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.rule_condition/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:rule_condition/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.set_subnets_opts/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:set_subnets_opts/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.subnet_mapping/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:subnet_mapping/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.tag/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:tag/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.target_description/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:target_description/0"},{"type":"type","title":"ExAws.ElasticLoadBalancingV2.target_group_attribute/0","doc":"","ref":"ExAws.ElasticLoadBalancingV2.html#t:target_group_attribute/0"},{"type":"extras","title":"AWS Elastic Load Balancing API","doc":"# AWS Elastic Load Balancing API\n\nAWS Elastic Load Balancing Service module for [ex_aws](https://github.com/ex-aws/ex_aws).\nAWS Elastic Load Balancing consists of two different API's that are grouped under the general\nheading of \"Elastic Load Balancing\". Both are included in this library. `ExAws.ElasticLoadBalancing`\nis used for what Amazon calls \"Classic\" Load Balancers. `ExAws.ElasticLoadBalancingV2`\nis used for Application or Network Load Balancers (alb/nlb).","ref":"readme.html"},{"type":"extras","title":"Installation - AWS Elastic Load Balancing API","doc":"The package can be installed by adding ex_aws_elastic_load_balancing to your\nlist of dependencies in mix.exs along with :ex_aws and your\npreferred JSON codec / http client. Example:\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.0\"},\n    {:ex_aws_elastic_load_balancing, \"~> 2.2\"},\n    {:poison, \"~> 3.0\"},\n    {:hackney, \"~> 1.9\"},\n  ]\nend\n```\n\nSimple usage from command line:\n\n```elixir\niex(1)> alias ExAws.ElasticLoadBalancing\nExAws.ElasticLoadBalancing\niex(2)>  keys = [secret_access_key: \"my_secret_keys\",  access_key_id: \"my_access_id\", region: \"us-east-1\"]\n[secret_access_key: \"my_secret_keys\",\n access_key_id: \"my_access_id\", region: \"us-east-1\"]\niex(3)>  ElasticLoadBalancing.describe_load_balancers() |> ExAws.request(keys)\n```","ref":"readme.html#installation"},{"type":"extras","title":"Other Notes - AWS Elastic Load Balancing API","doc":"Both AWS Elastic Load Balancing APIs use the \"query\" protocol. So every function in the API\nreturns a `%ExAws.Operation.Query{}` struct.\n\nMost of the unit tests are implemented using [DocTest](https://hexdocs.pm/ex_unit/ExUnit.DocTest.html).","ref":"readme.html#other-notes"},{"type":"extras","title":"License - AWS Elastic Load Balancing API","doc":"[License](LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"v2.2.1\n\n* Bug Fix: CanonicalHostedZoneId support added to ExAws.ElasticLoadBalancingV2.Parsers\n* Enhancement: Switch to main branch\n* Enhancement: Use Github Workflows to test with multiple Elixir versions, credo, dialyzer\n* Enhancement: Update dependencies\n\nv2.1.1\n  * Provide alternative param format for add_tags on v2 to align with classic add_tags\n\nv2.1.0\n  * Implement all the other classic load balancer functions\n\nv2.0.2\n  * Initial published version to hex.pm","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2018 Vonage, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}